@@ -28,7 +28,7 @@ class SageHistoryExtension : public Cantor::HistoryExtension
   public:
     SageHistoryExtension( QObject* parent );
     ~SageHistoryExtension();
-  public slots:
+  public Q_SLOTS:
     QString lastResult();
 };
 
@@ -37,7 +37,7 @@ class SageScriptExtension : public Cantor::ScriptExtension
   public:
     SageScriptExtension(QObject* parent);
     ~SageScriptExtension();
-  public slots:
+  public Q_SLOTS:
     virtual QString runExternalScript(const QString& path);
     virtual QString scriptFileFilter();
     virtual QString highlightingMode();
@@ -49,7 +49,7 @@ class SageCASExtension : public Cantor::CASExtension
     SageCASExtension( QObject* parent);
     ~SageCASExtension();
 
-  public slots:
+  public Q_SLOTS:
     virtual QString solve(const QStringList& equations, const QStringList& variables);
     virtual QString simplify(const QString& expression);
     virtual QString expand(const QString& expression);
@@ -62,7 +62,7 @@ class SageCalculusExtension : public Cantor::CalculusExtension
     SageCalculusExtension( QObject* parent);
     ~SageCalculusExtension();
 
-  public slots:
+  public Q_SLOTS:
     QString limit(const QString& expression, const QString& variable, const QString& limit);
     QString differentiate(const QString& function,const QString& variable, int times);
     QString integrate(const QString& function, const QString& variable);
@@ -75,7 +75,7 @@ class SageLinearAlgebraExtension : public Cantor::LinearAlgebraExtension
     SageLinearAlgebraExtension( QObject* parent);
     ~SageLinearAlgebraExtension();
 
-  public slots:
+  public Q_SLOTS:
     //Commands to create Vectors/Matrices
     QString createVector(const QStringList& entries, VectorType type);
     QString nullVector(int size, VectorType type);
@@ -96,7 +96,7 @@ class SagePlotExtension : public Cantor::PlotExtension
   public:
     SagePlotExtension(QObject* parent);
     ~SagePlotExtension();
-  public slots:
+  public Q_SLOTS:
     QString plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right);
     QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2);
 };
@@ -107,7 +107,7 @@ class SagePackagingExtension : public Cantor::PackagingExtension
     SagePackagingExtension(QObject* parent);
     ~SagePackagingExtension();
 
-  public slots:
+  public Q_SLOTS:
     virtual QString importPackage(const QString& module);
 };
 
